@@ -7,7 +7,9 @@
 wrapped_expect_doppelganger <- function(title, fig, path = NULL, ...) {
   testthat::skip_if_not_installed("vdiffr")
   vdiffr::expect_doppelganger(
-    title, fig,
+    title,
+    fig,
     # path = path,
-    ...)
+    ...
+  )
 }
